changeset 778:cd00bdacc17b

*** empty log message ***
author Jim Blandy <jimb@redhat.com>
date Wed, 15 Jul 1992 02:24:58 +0000
parents c99faf9381bb
children c2dbf1fe0506
files lisp/=diary-lib.el lisp/=isearch-old.el lisp/calendar/holidays.el lisp/comint.el lisp/dired.el lisp/electric.el lisp/emacs-lisp/edebug.el lisp/emerge.el lisp/files.el lisp/progmodes/compile.el lisp/progmodes/fortran.el lisp/textmodes/=ispell4.el
diffstat 12 files changed, 40 insertions(+), 40 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/=diary-lib.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/=diary-lib.el	Wed Jul 15 02:24:58 1992 +0000
@@ -261,7 +261,7 @@
     (if (or (not diary-entries-list)
             (and (not (cdr diary-entries-list))
                  (string-equal (car (cdr (car diary-entries-list))) "")))
-        (if (<= (length msg) (screen-width))
+        (if (<= (length msg) (frame-width))
             (message msg)
           (set-buffer (get-buffer-create holiday-buffer))
           (setq buffer-read-only nil)
@@ -295,7 +295,7 @@
              (msg (format "No diary entries for %s %s"
                           (concat date-string (if holiday-list ":" ""))
                           (mapconcat 'identity holiday-list "; "))))
-        (if (<= (length msg) (screen-width))
+        (if (<= (length msg) (frame-width))
             (message msg)
           (set-buffer (get-buffer-create holiday-buffer))
           (setq buffer-read-only nil)
--- a/lisp/calendar/holidays.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/calendar/holidays.el	Wed Jul 15 02:24:58 1992 +0000
@@ -71,7 +71,7 @@
          (msg (format "%s:  %s" date-string holiday-string)))
     (if (not holiday-list)
         (message "No holidays known for %s" date-string)
-      (if (<= (length msg) (screen-width))
+      (if (<= (length msg) (frame-width))
           (message msg)
         (set-buffer (get-buffer-create holiday-buffer))
         (setq buffer-read-only nil)
--- a/lisp/comint.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/comint.el	Wed Jul 15 02:24:58 1992 +0000
@@ -343,7 +343,7 @@
   (let ((process-environment
 	 (comint-update-env process-environment
 			    (list (format "TERMCAP=emacs:co#%d:tc=unknown"
-					  (screen-width))
+					  (frame-width))
 				  "TERM=emacs"
 				  "EMACS=t"))))
     (apply 'start-process name buffer command switches)))
--- a/lisp/electric.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/electric.el	Wed Jul 15 02:24:58 1992 +0000
@@ -144,7 +144,7 @@
 ;; 	Switch to buffer in the current window.
 ;;
 ;; Then if max-height is nil, and not all of the lines in the buffer
-;; are displayed, grab the whole screen.
+;; are displayed, grab the whole frame.
 ;;
 ;; Returns selected window on buffer positioned at point-min.
 
--- a/lisp/emacs-lisp/edebug.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/emacs-lisp/edebug.el	Wed Jul 15 02:24:58 1992 +0000
@@ -1694,14 +1694,14 @@
 
 
 (defun edebug-current-window-configuration ()
-  "Return the current window or screen configuration."
+  "Return the current window or frame configuration."
   (if edebug-epoch-running
       (edebug-current-screen-configuration)
     (current-window-configuration)))
 
 
 (defun edebug-set-window-configuration (conf)
-  "Set the window or screen configuration to CONF."
+  "Set the window or frame configuration to CONF."
   (if edebug-epoch-running
       (edebug-set-screen-configuration conf)
     (set-window-configuration conf)))
@@ -1714,7 +1714,7 @@
 
 
 (defun edebug-pop-to-buffer (buffer)
-  "Like pop-to-buffer, but select a screen that buffer was shown in."
+  "Like pop-to-buffer, but select a frame that buffer was shown in."
   (let ((edebug-window (edebug-get-buffer-window buffer)))
     (if edebug-window
 	(select-window edebug-window)
--- a/lisp/files.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/files.el	Wed Jul 15 02:24:58 1992 +0000
@@ -224,10 +224,10 @@
   (let ((pop-up-windows t))
     (pop-to-buffer buffer t)))
 
-(defun switch-to-buffer-other-screen (buffer)
-  "Switch to buffer BUFFER in another screen."
-  (interactive "BSwitch to buffer in other screen: ")
-  (let ((pop-up-screens t))
+(defun switch-to-buffer-other-frame (buffer)
+  "Switch to buffer BUFFER in another frame."
+  (interactive "BSwitch to buffer in other frame: ")
+  (let ((pop-up-frames t))
     (pop-to-buffer buffer)))
 
 (defun find-file (filename)
@@ -244,12 +244,12 @@
   (interactive "FFind file in other window: ")
   (switch-to-buffer-other-window (find-file-noselect filename)))
 
-(defun find-file-other-screen (filename)
-  "Edit file FILENAME, in another screen.
-May create a new screen, or reuse an existing one.
+(defun find-file-other-frame (filename)
+  "Edit file FILENAME, in another frame.
+May create a new frame, or reuse an existing one.
 See the function `display-buffer'."
-  (interactive "FFind file in other screen: ")
-  (switch-to-buffer-other-screen (find-file-noselect filename)))
+  (interactive "FFind file in other frame: ")
+  (switch-to-buffer-other-frame (find-file-noselect filename)))
 
 (defun find-file-read-only (filename)
   "Edit file FILENAME but don't allow changes.
@@ -267,12 +267,12 @@
   (find-file filename)
   (setq buffer-read-only t))
 
-(defun find-file-read-only-other-screen (filename)
-  "Edit file FILENAME in another screen but don't allow changes.
-Like \\[find-file-other-screen] but marks buffer as read-only.
+(defun find-file-read-only-other-frame (filename)
+  "Edit file FILENAME in another frame but don't allow changes.
+Like \\[find-file-other-frame] but marks buffer as read-only.
 Use \\[toggle-read-only] to permit editing."
-  (interactive "fFind file read-only other screen: ")
-  (find-file-other-screen filename)
+  (interactive "fFind file read-only other frame: ")
+  (find-file-other-frame filename)
   (setq buffer-read-only t))
 
 (defun find-alternate-file (filename)
@@ -1394,9 +1394,9 @@
 (define-key ctl-x-4-map "b" 'switch-to-buffer-other-window)
 (define-key ctl-x-4-map "o" 'display-buffer)
 
-(define-key ctl-x-5-map "b" 'switch-to-buffer-other-screen)
-(define-key ctl-x-5-map "f" 'find-file-other-screen)
-(define-key ctl-x-5-map "\C-f" 'find-file-other-screen)
-(define-key ctl-x-5-map "r" 'find-file-read-only-other-screen)
+(define-key ctl-x-5-map "b" 'switch-to-buffer-other-frame)
+(define-key ctl-x-5-map "f" 'find-file-other-frame)
+(define-key ctl-x-5-map "\C-f" 'find-file-other-frame)
+(define-key ctl-x-5-map "r" 'find-file-read-only-other-frame)
 
 ;;; files.el ends here
--- a/lisp/progmodes/compile.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/progmodes/compile.el	Wed Jul 15 02:24:58 1992 +0000
@@ -289,7 +289,7 @@
       (or (eq outwin (selected-window))
 	  (set-window-point outwin (point-min)))
       (and compilation-window-height
-	   (= (window-width outwin) (screen-width))
+	   (= (window-width outwin) (frame-width))
 	   (let ((w (selected-window)))
 	     (unwind-protect
 		 (progn
--- a/lisp/progmodes/fortran.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/progmodes/fortran.el	Wed Jul 15 02:24:58 1992 +0000
@@ -485,8 +485,8 @@
   (condition-case error
       (progn
 	(let ((window-min-width 2))
-	  (if (< (window-width) (screen-width))
-	      (enlarge-window-horizontally (- (screen-width)
+	  (if (< (window-width) (frame-width))
+	      (enlarge-window-horizontally (- (frame-width)
 					      (window-width) 1)))
 	  (split-window-horizontally 73)
 	  (other-window 1)
--- a/lisp/textmodes/=ispell4.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/textmodes/=ispell4.el	Wed Jul 15 02:24:58 1992 +0000
@@ -416,7 +416,7 @@
     ret))
 
 (defun ispell-show-choices (word message first-line)
-  ;;if there is only one window on the screen, make the ispell
+  ;;if there is only one window on the frame, make the ispell
   ;;messages winow be small.  otherwise just use the other window
   (let* ((selwin (selected-window))
 	 (resize (eq selwin (next-window)))
--- a/lisp/=isearch-old.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/=isearch-old.el	Wed Jul 15 02:24:58 1992 +0000
@@ -166,7 +166,7 @@
 	;; non-nil means an explicit uppercase letter seen in the input
 	(uppercase-flag nil)
 	;; Non-nil means start using a small window
-	;; if the search moves outside what is currently on the screen.
+	;; if the search moves outside what is currently on the frame.
 	(slow-terminal-mode (and (<= baud-rate search-slow-speed)
 				 (> (window-height)
 				    (* 4 search-slow-window-lines))))
@@ -183,8 +183,8 @@
 	;; for moving the cursor back on quitting.
 	(opoint (point))
 	(inhibit-quit t)  ;Prevent ^G from quitting, so we can read it.
-	;; The screen we're working on; if this changes, we exit isearch.
-	(screen (if (fboundp 'selected-screen) (selected-screen))))
+	;; The frame we're working on; if this changes, we exit isearch.
+	(frame (if (fboundp 'selected-frame) (selected-frame))))
 	   
     (isearch-push-state)
     (save-window-excursion
@@ -225,8 +225,8 @@
 		  (setq unread-command-char char)
 		  (throw 'search-done t))
 
-		 ;; If the user switches to a different screen, exit.
-		 ((not (eq screen last-event-screen))
+		 ;; If the user switches to a different frame, exit.
+		 ((not (eq frame last-event-frame))
 		  (setq unread-command-char char)
 		  (throw 'search-done t))
 
--- a/lisp/dired.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/dired.el	Wed Jul 15 02:24:58 1992 +0000
@@ -1389,12 +1389,12 @@
       (cond ;; if split-window-threshold is enabled, use the largest window
             ((and (> (window-height (setq w2 (get-largest-window)))
 		     split-height-threshold)
-		  (= (screen-width) (window-width w2)))
+		  (= (frame-width) (window-width w2)))
 	     (setq window w2))
 	    ;; if the least-recently-used window is big enough, use it
 	    ((and (> (window-height (setq w2 (get-lru-window)))
 		     (* 2 window-min-height))
-		  (= (screen-width) (window-width w2)))
+		  (= (frame-width) (window-width w2)))
 	     (setq window w2)))
       (save-excursion
 	(set-buffer buf)
@@ -1402,7 +1402,7 @@
 	(skip-chars-backward "\n\r\t ")
 	(setq target-lines (count-lines (point-min) (point))))
       (if (<= (window-height window) (* 2 window-min-height))
 	  ;; At this point, every window on the screen is too small to split.
 	  (setq w2 (display-buffer buf))
 	(setq w2 (split-window window
 		  (max window-min-height
@@ -1402,7 +1402,7 @@
 	(setq target-lines (count-lines (point-min) (point))))
       (if (<= (window-height window) (* 2 window-min-height))
-	  ;; At this point, every window on the screen is too small to split.
+	  ;; At this point, every window on the frame is too small to split.
 	  (setq w2 (display-buffer buf))
 	(setq w2 (split-window window
--- a/lisp/emerge.el	Wed Jul 15 00:32:19 1992 +0000
+++ b/lisp/emerge.el	Wed Jul 15 02:24:58 1992 +0000
@@ -400,7 +400,7 @@
 ; number of lines or characters by which the windows are scrolled.
 ; Otherwise, the amount of motion is computed based on the dimensions of
 ; the merge buffer window -- the height of the merge buffer window
 ; (minus next-screen-context-lines), or half the width of the merge
 ; buffer window.  (The A and B version windows are assumed to be as high
 ; as the merge window, but half as wide.)  If the argument is just `C-u
 ; -', then the scrolling is half the default amount.
@@ -2898,7 +2898,7 @@
       (if (not (pos-visible-in-window-p))
 	  (let ((echo-keystrokes 0))
 	    (while (and (not (pos-visible-in-window-p))
-			(> (1- (screen-height)) (window-height)))
+			(> (1- (frame-height)) (window-height)))
 	      (enlarge-window 1))
 	    (let ((c (read-char)))
 	      (if (/= c 32)
@@ -400,7 +400,7 @@
 ; Otherwise, the amount of motion is computed based on the dimensions of
 ; the merge buffer window -- the height of the merge buffer window
-; (minus next-screen-context-lines), or half the width of the merge
+; (minus next-frame-context-lines), or half the width of the merge
 ; buffer window.  (The A and B version windows are assumed to be as high
 ; as the merge window, but half as wide.)  If the argument is just `C-u